@@ -26,9 +26,6 @@ except ImportError:
     HAS_NUMPY = False
 
 
-version_info = (version_info.major, version_info.minor)
-
-
 class TestCase(unittest.TestCase):
     """testing of asteval"""
     def setUp(self):
@@ -135,6 +132,9 @@ class TestCase(unittest.TestCase):
 class TestEval(TestCase):
     """testing of asteval"""
 
+    def test_py3(self):
+        assert version_info.major > 2
+
     def test_dict_index(self):
         """dictionary indexing"""
         self.interp("a_dict = {'a': 1, 'b': 2, 'c': 3, 'd': 4}")
@@ -460,11 +460,12 @@ class TestEval(TestCase):
     def test_syntaxerrors_1(self):
         """assignment syntax errors test"""
         for expr in ('class = 1', 'for = 1', 'if = 1', 'raise = 1',
-                     '1x = 1', '1.x = 1', '1_x = 1'):
+                     '1x = 1', '1.x = 1', '1_x = 1',
+                     'return 3', 'return False'):
             failed = False
             # noinspection PyBroadException
             try:
-                self.interp(expr, show_errors=False)
+                self.interp(expr, show_errors=False, raise_errors=True)
             except:
                 failed = True
 
@@ -477,7 +478,7 @@ class TestEval(TestCase):
             failed = False
             # noinspection PyBroadException
             try:
-                self.interp(expr, show_errors=False)
+                self.interp(expr, show_errors=False, raise_errors=True)
             except:
                 failed = True
             self.assertTrue(failed)
@@ -489,7 +490,7 @@ class TestEval(TestCase):
             failed = False
             # noinspection PyBroadException
             try:
-                self.interp(expr, show_errors=False)
+                self.interp(expr, show_errors=False, raise_errors=True)
             except:  # RuntimeError:
                 failed = True
             self.assertTrue(failed)
@@ -513,7 +514,7 @@ class TestEval(TestCase):
             failed, errtype, errmsg = False, None, None
             # noinspection PyBroadException
             try:
-                self.interp(expr, show_errors=False)
+                self.interp(expr, show_errors=False, raise_errors=True)
             except:
                 failed = True
             self.assertTrue(failed)
@@ -628,7 +629,7 @@ class TestEval(TestCase):
             self.interp.error = []
             # noinspection PyBroadException
             try:
-                self.interp("%s= 2" % w, show_errors=False)
+                self.interp("%s= 2" % w, show_errors=False, raise_errors=True)
             except:
                 pass
 
@@ -879,10 +880,12 @@ class TestEval(TestCase):
         self.check_error('RuntimeError')
         self.interp("'*'*(2<<17) + '*'")
         self.check_error('RuntimeError')
-        self.interp("10**10000")
+        self.interp("1.01**10000")
         self.check_error(None)
-        self.interp("10**10001")
+        self.interp("1.01**10001")
         self.check_error('RuntimeError')
+        self.interp("1.5**10000")
+        self.check_error('OverflowError')
         self.interp("1<<1000")
         self.check_error(None)
         self.interp("1<<1001")
@@ -915,7 +918,7 @@ class TestEval(TestCase):
         self.check_error('RuntimeError')  # Safe, safe_pow() catches this
         self.interp(
             "x = ((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((1))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))")
-        if version_info == (3, 9):
+        if version_info.minor > 8:
             self.isvalue('x', 1)
             self.check_error(None)
         else:
